==> moodle_1.3.1.orig.tar.gz: moodle/lang/es/dialogue.php <==
<?PHP // $Id: dialogue.php,v 1.7 2004/05/27 08:16:18 barias Exp $ 
      // dialogue.php - created with Moodle 1.3 (2004052500)


$string['addmynewentries'] = 'Agregar mis nuevas entradas';
$string['addmynewentry'] = 'Agregar mi nueva entrada';
$string['addsubject'] = 'Agregar tema';
$string['allowmultiple'] = 'Permitir ms de un dilogo con la misma persona';
$string['allowstudentdialogues'] = 'Permitir dilogos entre estudiantes';
$string['close'] = 'Cerrar';
$string['closed'] = 'Cerrado';
$string['confirmclosure'] = 'Est a punto de cerrar su dilogo con $a. Los dilogos ya cerradosno se pueden volver a abrir. Si cierra este dilogo podr consultarlo pero ya no podr intervenir en l, y deber iniciar un nuev dilogo con la misma persona para continuar la conversacin. Est seguro de que desea cerrarlo?';
$string['deleteafter'] = 'Borrar dilogos cerrados despus de (Das)';
$string['dialogueclosed'] = 'Dilogo cerrado';
$string['dialogueintro'] = 'Introduccin al dilogo';
$string['dialoguemail'] = '$a->userfrom ha respondido a su intervencin en el dilogo \'$a->dialogue\'
Puede verlo junto a su intervencin en:
    $a->url';
$string['dialoguemailhtml'] = 'El usuario $a->userfrom ha respondido a su intervencin en el dilogo \'<i>$a->dialogue</i>\'<br /><br />
Puede verlo adjunto <a href=\"$a->url\">aqu</a>.';
$string['dialoguename'] = 'Nombre del dilogo';
$string['dialogueopened'] = 'Dilogo abierto con $a';
$string['dialoguewith'] = 'Dilogo con $a';
$string['everybody'] = 'Todos';
$string['furtherinformation'] = 'Informacin complementaria';
$string['lastentry'] = 'Ultima participacin';
$string['maildefault'] = 'Correo electrnico por defecto';
$string['modulename'] = 'Dilogo';
$string['modulenameplural'] = 'Dilogos';
$string['namehascloseddialogue'] = '$a ha cerrado el dilogo';
$string['newdialogueentries'] = 'Nuevas intervenciones en el dilogo';
$string['newentry'] = 'Nueva intervencin';
$string['noavailablepeople'] = 'No hay nadie disponible para dialogar.';
$string['nopersonchosen'] = 'No se ha elegido interlocutor';
$string['nosubject'] = 'No se ha elegido tema';
$string['notextentered'] = 'No se ha includo texto';
$string['notstarted'] = 'Usted no ha iniciado una charla an';
$string['notyetseen'] = 'An no ha sido ledo';
$string['numberofentries'] = 'Nmero de intervenciones';
$string['numberofentriesadded'] = 'Nmero de intervenciones agregadas: $a';
$string['of'] = 'de';
$string['onwrote'] = 'El $a escribi';
$string['onyouwrote'] = 'El $a usted escribi';
$string['open'] = 'Abierto';
$string['openadialoguewith'] = 'Dilogo abierto con';
$string['opendialogue'] = 'Iniciar dilogo';
$string['opendialogueentries'] = 'Abrir entradas del dilogo';
$string['pane0'] = 'Iniciar un dilogo';
$string['pane1'] = '$a dilogos esperan su respuesta';
$string['pane1one'] = 'Un dilogo espera su respuesta';
$string['pane2'] = '$a dilogos esperando respuestas de la otra persona';
$string['pane2one'] = '1 dilogo esperando una respuesta de la otra persona';
$string['pane3'] = '$a dilogos cerrados';
$string['pane3one'] = '1 dilogo cerrado';
$string['seen'] = 'Visto hace $a';
$string['sendmailmessages'] = 'Enviar correos electrnicos con mis nuevas entradas';
$string['status'] = 'Estatus';
$string['studenttostudent'] = 'Estudiante a Estudiante';
$string['subject'] = 'Tema';
$string['subjectadded'] = 'Tema agregado';
$string['teachertostudent'] = 'Profesor a Estudiante';
$string['typefirstentry'] = 'Escriba la primera entrada aqu';
$string['typefollowup'] = 'Escriba la continuacin aqu';
$string['typeofdialogue'] = 'Tipo de dilogo';
$string['typereply'] = 'Escriba la respuesta aqu';
$string['viewallentries'] = ' Ver entradas a dilogo de $a';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/es/dialogue.php <==
<?PHP // $Id$ 
      // dialogue.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004092700)


$string['addmynewentries'] = 'Agregar mis nuevas entradas';
$string['addmynewentry'] = 'Agregar mi nueva entrada';
$string['addsubject'] = 'Agregar tema';
$string['allowmultiple'] = 'Permitir ms de un dilogo con la misma persona';
$string['allowstudentdialogues'] = 'Permitir dilogos entre estudiantes';
$string['close'] = 'Cerrar';
$string['closed'] = 'Cerrado';
$string['confirmclosure'] = 'Est a punto de cerrar su dilogo con $a. Los dilogos ya cerradosno se pueden volver a abrir. Si cierra este dilogo podr consultarlo pero ya no podr intervenir en l, y deber iniciar un nuev dilogo con la misma persona para continuar la conversacin. Est seguro de que desea cerrarlo?';
$string['deleteafter'] = 'Borrar dilogos cerrados despus de (Das)';
$string['dialogueclosed'] = 'Dilogo cerrado';
$string['dialogueintro'] = 'Introduccin al dilogo';
$string['dialoguemail'] = '$a->userfrom ha respondido a su intervencin en el dilogo \'$a->dialogue\'
Puede verlo junto a su intervencin en:
    $a->url';
$string['dialoguemailhtml'] = 'El usuario $a->userfrom ha respondido a su intervencin en el dilogo \'<i>$a->dialogue</i>\'<br /><br />
Puede verlo adjunto <a href=\"$a->url\">aqu</a>.';
$string['dialoguename'] = 'Nombre del dilogo';
$string['dialogueopened'] = 'Dilogo abierto con $a';
$string['dialoguewith'] = 'Dilogo con $a';
$string['everybody'] = 'Todos';
$string['furtherinformation'] = 'Informacin complementaria';
$string['lastentry'] = 'Ultima participacin';
$string['maildefault'] = 'Correo electrnico por defecto';
$string['mailnotification'] = 'Notificacin por email';
$string['modulename'] = 'Dilogo';
$string['modulenameplural'] = 'Dilogos';
$string['namehascloseddialogue'] = '$a ha cerrado el dilogo';
$string['newdialogueentries'] = 'Nuevas intervenciones en el dilogo';
$string['newentry'] = 'Nueva intervencin';
$string['noavailablepeople'] = 'No hay nadie disponible para dialogar.';
$string['nopersonchosen'] = 'No se ha elegido interlocutor';
$string['nosubject'] = 'No se ha elegido tema';
$string['notextentered'] = 'No se ha includo texto';
$string['notstarted'] = 'Usted no ha iniciado una charla an';
$string['notyetseen'] = 'An no ha sido ledo';
$string['numberofentries'] = 'Nmero de intervenciones';
$string['numberofentriesadded'] = 'Nmero de intervenciones agregadas: $a';
$string['of'] = 'de';
$string['onwrote'] = 'El $a escribi';
$string['onyouwrote'] = 'El $a usted escribi';
$string['open'] = 'Abierto';
$string['openadialoguewith'] = 'Dilogo abierto con';
$string['opendialogue'] = 'Iniciar dilogo';
$string['opendialogueentries'] = 'Abrir entradas del dilogo';
$string['pane0'] = 'Iniciar un dilogo';
$string['pane1'] = '$a dilogos esperan su respuesta';
$string['pane1one'] = 'Un dilogo espera su respuesta';
$string['pane2'] = '$a dilogos esperando respuestas de la otra persona';
$string['pane2one'] = '1 dilogo esperando una respuesta de la otra persona';
$string['pane3'] = '$a dilogos cerrados';
$string['pane3one'] = '1 dilogo cerrado';
$string['seen'] = 'Visto hace $a';
$string['sendmailmessages'] = 'Enviar correos electrnicos con mis nuevas entradas';
$string['status'] = 'Estatus';
$string['studenttostudent'] = 'Estudiante a Estudiante';
$string['subject'] = 'Tema';
$string['subjectadded'] = 'Tema agregado';
$string['teachertostudent'] = 'Profesor a Estudiante';
$string['typefirstentry'] = 'Escriba la primera entrada aqu';
$string['typefollowup'] = 'Escriba la continuacin aqu';
$string['typeofdialogue'] = 'Tipo de dilogo';
$string['typereply'] = 'Escriba la respuesta aqu';
$string['viewallentries'] = ' Ver entradas a dilogo de $a';

?>
